# fannypack

![build](https://github.com/brentyi/fannypack/workflows/build/badge.svg)
![mypy](https://github.com/brentyi/fannypack/workflows/mypy/badge.svg?branch=master)
![lint](https://github.com/brentyi/fannypack/workflows/lint/badge.svg)
[![codecov](https://codecov.io/gh/brentyi/fannypack/branch/master/graph/badge.svg)](https://codecov.io/gh/brentyi/fannypack)

Helpers for PyTorch.

Standard installation:
```
pip install fannypack
```

Github:
https://github.com/brentyi/fannypack

Documentation (work-in-progress):
https://brentyi.github.io/fannypack
